@@ -23,8 +23,7 @@ import hardware
 from textlog import LogTrack
 import exputils
 
-import Numeric
-import RandomArray
+import numpy
 import timing
 
 # method for setting realtime
@@ -835,11 +834,11 @@ def mathDistract(clk = None,
     #v.clear("black")
 
     # generate a bunch of math problems
-    vars = RandomArray.uniform(minNum,maxNum,[maxProbs, numVars]).astype(Numeric.Int16)
+    vars = numpy.random.randint(minNum,maxNum+1,[maxProbs, numVars])
     if plusAndMinus:
-        pm = Numeric.sign(RandomArray.uniform(-1,1,[maxProbs, numVars-1]))
+        pm = numpy.sign(numpy.random.uniform(-1,1,[maxProbs, numVars-1]))
     else:
-        pm = Numeric.ones([maxProbs, numVars-1])
+        pm = numpy.ones([maxProbs, numVars-1])
 
     # see if T/F or numeric answers
     if isinstance(tfKeys,tuple):
@@ -853,7 +852,7 @@ def mathDistract(clk = None,
         if sum(ansProb) != 1.0:
             # raise error
             pass
-        ansProb = Numeric.cumsum(ansProb)
+        ansProb = numpy.cumsum(ansProb)
     else:
 	# not t/f problems 
         tfProblems = False
@@ -896,7 +895,10 @@ def mathDistract(clk = None,
         if tfProblems:
             # determine the displayed answer
             # see which answermod
-            ansInd = min(Numeric.nonzero(ansProb >= RandomArray.uniform(0,1)))
+            ansInd = numpy.nonzero(ansProb >= numpy.random.uniform(0,1))
+            if isinstance(ansInd,tuple):
+                ansInd = ansInd[0]
+            ansInd = min(ansInd)
             disp_ans = cor_ans + ansMod[ansInd]
 
             # see if is True or False
