@@ -678,19 +678,20 @@ class Text(Showable, Stimulus):
             
         # set the rendered text to None (not rendered)
         self.rendered = None
-
     def __getstate__(self):
         """
         Don't give the rendered form to pickle.
         """
-        # LowImages are not picklable, so we exluded the rendered text from the state
-        return self.text, self.color, self.propsize, self.font
+        # remove the LowImage object before pickle looks at the data (because LowImages are not picklable)
+        d = self.__dict__.copy()
+        del d["rendered"]
+        return d
     def __setstate__(self, state):
         """
         After unpickling, the text should NOT be rendered.
         """
-        # we excluded the rendered text from the state, so now we have to set it to None
-        self.text, self.color, self.propsize, self.font = state
+        # unpickle with None as self.image (since we left it out when we pickled)
+        self.__dict__.update(state)
         self.rendered = None
     def render(self):
         # make sure the font is loaded
