@@ -89,6 +89,10 @@ class Experiment:
 
     sync_to_vbl - Boolean, if True, waits for screen's vertical
     retrace before drawing - DEFAULT: True
+    
+    max_facet_length - The maximum length, in VR units, for 3D facets.
+    Larger facets will be broken into smaller pieces for display.
+    DEFAULT: 10.0
     """
     # set the default options...
     defaults = {
@@ -100,7 +104,8 @@ class Experiment:
         "fullscreen": True,
         "joystick_zero_threshold": 0.2,
         "use_eeg": True,
-	"sync_to_vbl": True
+	"sync_to_vbl": True,
+        "max_facet_length": 10.0
         }
     def __init__(self, **options):
         """
@@ -207,6 +212,9 @@ class Experiment:
 	    eplopts.add_option("--no-screen-sync", action = "store_false", default = defaults["sync_to_vbl"],
 			       dest = "sync_to_vbl",
 			       help = "Do not enable synchronization with the screen's vertical retrace.")
+	    eplopts.add_option("--max-facet-length", type = "float", default = defaults["max_facet_length"],
+			       dest = "max_facet_length", metavar = "MAXLENGTH",
+			       help = "Set the maximum length, in VR units, for 3D facets.  Larger facets will be broken into smaller pieces for display.")
 
 	    # add the group to the optparser
 	    parser.add_option_group(eplopts)
