@@ -7,9 +7,15 @@
 # Distributed under the terms of the GNU Lesser General Public License
 # (LGPL). See the license.txt that came with this file.
 
-from pulse import openPort, closePort, setState, setSignal, EPLPulseEEGException
 from scalp import shmAttached, shmAttach, shmDetach, recStart, recStop, getOffset, EPLScalpEEGException
 
+import sys
+
+if sys.platform=='darwin':
+    from pulse import awCard
+else:
+    from pulse import openPort, closePort, setState, setSignal, EPLPulseEEGException
+
 def initialize(**options):
     """
     """
