@@ -10,7 +10,7 @@
 import sys
 from pulseexc import EPLPulseEEGException
 if sys.platform=='darwin':
-    from macpulse import *	
+    from awCard import awCard
 else:
     from pulse import *
 
