@@ -14,7 +14,7 @@ This module provides functions for playing and recording sounds.
 # import python modules
 import time
 import threading
-import Numeric
+import numpy
 import math
 import struct
 import copy
@@ -70,7 +70,7 @@ class AudioClip(Stimulus):
         Strip the second channel from raw data in str form for saving.
         """
         # Convert to numeric array
-        xbuff = Numeric.array(struct.unpack(str(len(rawstr)/self.sampleWidth) + 'h', rawstr), typecode=Numeric.Int16)
+        xbuff = numpy.array(struct.unpack(str(len(rawstr)/self.sampleWidth) + 'h', rawstr), dtype=numpy.int16)
 	# Drop a channel
         xbuff = xbuff[::2]
 
@@ -85,7 +85,7 @@ class AudioClip(Stimulus):
 	make a 2-channel signal.
 	"""
 	# add the second channel
-	xbuff = Numeric.zeros((len(rawstr)*2), typecode=Numeric.Int16)
+	xbuff = numpy.zeros((len(rawstr)*2), dtype=numpy.int16)
 	xbuff[::2] = rawstr;
 	xbuff[1::2] = rawstr;
 
@@ -99,7 +99,7 @@ class AudioClip(Stimulus):
 	    self.snd = ''
 	if numchans==1:
 	    # double the data 
-	    buff = Numeric.array(struct.unpack(str(len(data)/self.sampleWidth) + 'h', data), typecode=Numeric.Int16)
+	    buff = numpy.array(struct.unpack(str(len(data)/self.sampleWidth) + 'h', data), dtype=numpy.int16)
 	    data = self.duplicateChannel(buff)
 
 	self.snd += data
@@ -169,17 +169,17 @@ class Beep(AudioClip):
 	sampRise = int(risefalltime*self.RESAMPLEDRATE/1000)
 
 	# Create the array at correct frequency
-	buff = Numeric.arange(0, sampDur*(2*math.pi)/sampCycle, (2*math.pi)/sampCycle)
-	buff = scale * Numeric.sin(buff)
+	buff = numpy.arange(0, sampDur*(2*math.pi)/sampCycle, (2*math.pi)/sampCycle)
+	buff = scale * numpy.sin(buff)
 
 	# Apply envelope
 	if risefalltime > 0:
-	    env = Numeric.arange(0, 1, float(1/float(sampRise)))
+	    env = numpy.arange(0, 1, float(1/float(sampRise)))
 	    buff[0:len(env)] = buff[0:len(env)]*env
 	    buff[-1:-(len(env)+1):-1] = buff[-1:-(len(env)+1):-1]*env
 	    
-	# convert to Int16
-	buff = buff.astype(Numeric.Int16)
+	# convert to int16
+	buff = buff.astype(numpy.int16)
 
 	# convert duplicate to a 2nd channel
 	self.snd = self.duplicateChannel(buff)
@@ -370,7 +370,7 @@ class FileAudioClip(MediaFile,AudioClip):
 
 	    # save the raw data to an array
 	    totalSamples = nf*self.fileSettings['channels']
-	    self.snd = Numeric.array(unpack(byteorder + str(totalSamples) + sizes[self.sampleWidth], data), typecode=Numeric.Int16)
+	    self.snd = numpy.array(unpack(byteorder + str(totalSamples) + sizes[self.sampleWidth], data), dtype=numpy.int16)
 	    if len(self.snd)==0:
 		raise SoundException("Sound file %s is empty." % self.filename)
 
@@ -400,15 +400,19 @@ class FileAudioClip(MediaFile,AudioClip):
 					self.fileSettings['channels'], 
 					self.fileSettings['sampleRate'])
 
-	if numchans==2:
+	if self.fileSettings['channels']==1 and numchans==2:
 	    # strip the second channel
-	    strippeddata = self.stripChannel(data)
+	    channelCorrectData = self.stripChannel(data)
+	elif self.fileSettings['channels']==2 and numchans==1:
+	    # duplicate the data so we have 2 channels
+	    channelCorrectData = self.duplicateChannel(data)
 	else:
-	    strippeddata = data
-	    
+	    # number of channels to append matches the number of channels in soundfile
+	    channelCorrectData = data
+
 	# append the data
-	soundFile.append_short(strippeddata, 
-			       len(strippeddata)/widthDict[self.fileSettings['sampleWidth']])
+	soundFile.append_short(channelCorrectData,
+			       len(channelCorrectData)/widthDict[self.fileSettings['sampleWidth']])
 	
 	del soundFile
 
@@ -624,13 +628,14 @@ class AudioTrack(textlog.LogTrack):
 	return self.eplsound.getSamplesPlayed()
 
         
-    def startRecording(self, basename = None, t = None):
+    def startRecording(self, basename = None, t = None, **sfargs):
         """
         Starts recording and returns a tuple of the AudioClip and the time
         of recording onset.
 
         INPUT ARGS:
           t- optional PresentationClock for timing.
+	  sfargs- keyword arguments for FileAudioClip constructor
 
         OUTPUT ARGS:
           recClip- The AudioClip object that will contain the recorded data.
@@ -640,9 +645,11 @@ class AudioTrack(textlog.LogTrack):
             # get a new audio clip to record to
 	    if not basename is None:
 		# send output to file
-		self.recClip = FileAudioClip(self.archive, basename)
+		self.recClip = FileAudioClip(self.archive, basename, **sfargs)
 	    else:
 		# record in memory
+		if len(sfargs)>0:
+		    raise SoundException("Cannot pass sfargs to AudioClip constructor; you must be recording to file.")
 		self.recClip = AudioClip()
 
             # start recording
@@ -731,7 +738,7 @@ class AudioTrack(textlog.LogTrack):
             del self.recClip
             return (r, timeInterval)
 
-    def record(self, duration, basename = None, t = None):
+    def record(self, duration, basename = None, t = None, **sfargs):
         """
         Perform a blocked recording for a specified duration (in milliseconds).
 
@@ -739,6 +746,7 @@ class AudioTrack(textlog.LogTrack):
           duration- length of time (in ms.) to record for.
           basename- filename to save recorded data to.
           t- optional PresentationClock for timing.
+	  sfargs- keyword arguments passed to FileAudioClip constructor
 
         OUTPUT ARGS:
           recClip- The AudioClip object that contains the recorded data.
@@ -750,7 +758,7 @@ class AudioTrack(textlog.LogTrack):
             clk = t
             t = clk.get()
             clk.delay(duration)
-        (r,starttime) = self.startRecording(basename, t = t)
+        (r,starttime) = self.startRecording(basename, t = t, **sfargs)
         (r,stoptime) = self.stopRecording(t = t + duration)
         return (r,starttime)
 
